@@ -45,7 +45,7 @@ def pytest_addoption(parser):
     group.addoption('--component-prefix', action='store', dest='mtr_component_prefix',
                     help='Prefix each found components with the given value (applies to all tests'
                          ' run in this session).')
-    group.addoption('--no-gc', action="store_true", dest="mtr_no_gc", 
+    group.addoption('--no-gc', action="store_true", dest="mtr_disable_gc", 
                     help='Disable garbage collection between tests (may leads to non reliable measures)')
     group.addoption('--description', action='store', default='', dest='mtr_description',
                     help='Use this option to provide a small summary about this run.')
@@ -157,7 +157,7 @@ def pytest_pyfunc_call(pyfuncitem):
     if not PYTEST_MONITORING_ENABLED:
         wrapped_function()
     else:
-        if pyfuncitem.session.config.option.mtr_no_gc:
+        if not pyfuncitem.session.config.option.mtr_disable_gc:
             gc.collect()
         prof()
     return True
